@@ -1,8 +1,10 @@
 import os
 import numpy as np
 import pytest
+from pathlib import Path
 from napari.layers import Image, Points, Labels, Shapes, Vectors
 from napari.utils.colormaps.colormap_utils import ensure_colormap
+from napari_svg.layer_to_xml import layer_transforms_to_xml_string
 from napari_svg import (
     napari_write_image,
     napari_write_labels,
@@ -93,6 +95,21 @@ def test_write_image_from_napari_layer_data(tmpdir, layer_writer_and_data):
     assert os.path.isfile(path)
 
 
+def test_write_rgb_image(tmp_path):
+    """Check that an rgb image can be correctly saved as svg."""
+    rng = np.random.default_rng(0)
+    image = np.random.randint(0, 256, size=(4, 4, 3), dtype=np.uint8)
+    path = tmp_path / 'rgb.svg'
+    return_path = napari_write_image(str(path), image, {'rgb': True})
+    assert str(path) == return_path
+    svg_txt = path.read_text()
+    assert 'data:image/png;base64' in svg_txt
+    # start and end of correct base64 encoding for this image
+    assert 'iVBOR' in svg_txt
+    assert 'uQmCC' in svg_txt
+
+
+
 def test_write_image_no_extension(tmpdir, layer_writer_and_data):
     """Test writing layer data with no extension."""
     writer, layer_data, _ = layer_writer_and_data
@@ -160,4 +177,64 @@ def test_write_image_colormaps_vispy(tmpdir, layer_writer_and_data, path_ensure,
     assert return_path == path
 
     # Check file now exists
-    assert os.path.isfile(path)
\ No newline at end of file
+    assert os.path.isfile(path)
+
+
+NOOP_TRANSFORM = layer_transforms_to_xml_string({
+    'scale': [1.0, 1.0],
+    'translate': [0.0, 0.0],
+    'shear': [0.0],
+    'rotate': [[1.0, 0.0], [0.0, 1.0]],
+    'affine': [[1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]],
+})
+NOOP_TRANSFORM_STR = f' transform="{NOOP_TRANSFORM}"'
+
+def test_write_points_with_attributes(request, tmp_path):
+    data = [
+        [0, 0],
+        [0, 128],
+        [128, 128],
+    ]
+    size = [16, 20, 24]
+    face_color = ['red', 'green', 'blue']
+    edge_color = ['cyan', 'magenta', 'yellow']
+    edge_width = [0.05, 0.25, 0.5]
+    layer = Points(
+        data,
+        opacity=0.5,
+        size=size,
+        face_color=face_color,
+        edge_color=edge_color,
+        edge_width=edge_width,
+        edge_width_is_relative=True,
+    )
+    test_name = request.node.name
+    path = tmp_path / f'{test_name}-actual.svg'
+    layer_data, layer_attrs, _ = layer.as_layer_data_tuple()
+
+    return_path = napari_write_points(path, layer_data, layer_attrs)
+    assert return_path == path
+
+    expected_path = Path(__file__).parent / f'{test_name}-expected.svg'
+    actual_text = path.read_text().replace(NOOP_TRANSFORM_STR, '')
+    expected_text = expected_path.read_text().replace(NOOP_TRANSFORM_STR, '')
+    assert actual_text == expected_text
+
+
+    def test_write_points_with_text(tmp_path):
+        data = [
+            [0, 0],
+            [0, 128],
+            [128, 128],
+        ]
+        text_data = ['car', 'crosswalk', 'bicycle']
+        layer = Points(data, text=text_data)
+        layer_data, layer_attrs, _ = layer.as_layer_data_tuple()
+
+        path = tmp_path / 'points-with-text.svg'
+        return_path = napari_write_points(path, layer_data, layer_attrs)
+        assert return_path == path
+
+        svg_text = path.read_text().replace(NOOP_TRANSFORM_STR, '')
+        for elem in text_data:
+            assert elem in svg_text
